from openfisca_tunisia.tunisia_taxbenefitsystem import TunisiaTaxBenefitSystem

# The name CountryTaxBenefitSystem must not be changed, as all tools of the OpenFisca
# ecosystem expect a CountryTaxBenefitSystem class to be exposed
# in the __init__ module of a country package.

CountryTaxBenefitSystem = TunisiaTaxBenefitSystem
